==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/zh_TW.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "Nextcloud 文字編輯器",
    "text document" : "文字文件",
    "Readme" : "說明",
    "Text" : "文字編輯器",
    "📝 Collaborative document editing" : "📝 協作文件編輯",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 協作文件編輯！**\n\n- **📝 聚焦編輯：** 沒有不重要的東西，只有你需要的格式化。\n- **🙋 共同作業：** 與朋友及同事協作，無關他們是否使用 Nextcloud！\n- **💾 開放格式：** 檔案會以 [Markdown](https://en.wikipedia.org/wiki/Markdown) 儲存，所以你也能在其他文字編輯器編輯。\n- **✊ 強大基礎：** 我們使用基於 [🦉 ProseMirror](https://prosemirror.net) 的 [🐈 tiptap](https://tiptap.scrumpy.io) – 超級感謝他們！",
    "Use current version" : "使用目前版本",
    "Use the saved version" : "使用儲存版本",
    "The document has been changed outside of the editor. The changes cannot be applied." : "文件已在編輯器外變更。變更無法套用。",
    "File could not be loaded. Please check your internet connection." : "無法載入檔案。請檢查您的網路連線。",
    "Retry" : "重試",
    "Last saved {lastSaved}" : "上次儲存於 {lastSaved}",
    "Unpushed changes" : "未推送變更",
    "Unsaved changes" : "未儲存變更",
    "Enter your name so other users can see who is editing" : "輸入您的名稱，這樣其他使用者才能查看是誰在編輯",
    "Edit guest name" : "編輯訪客名稱",
    "Save guest name" : "儲存訪客名稱",
    "Insert image" : "插入影像",
    "Add link" : "加入連結",
    "_and %n other editor_::_and %n other editors_" : ["及其他 %n 個編輯器"],
    "Show rich workspaces" : "顯示較多功能的工作區",
    "Add notes, lists or links …" : "加入筆記、清單或連結…",
    "New text document" : "新文字文件",
    "Edit" : "編輯",
    "Undo" : "復原",
    "Redo" : "重作",
    "Bold" : "粗體",
    "Italic" : "斜體",
    "Strikethrough" : "刪除線",
    "Paragraph" : "段落",
    "Headings" : "標題",
    "Heading 1" : "標題 1",
    "Heading 2" : "標題 2",
    "Heading 3" : "標題 3",
    "Heading 4" : "標題 4",
    "Heading 5" : "標題 5",
    "Heading 6" : "標題 6",
    "Unordered list" : "無序清單",
    "Ordered list" : "有序清單",
    "ToDo list" : "待辦列表",
    "Blockquote" : "引文",
    "Code block" : "程式碼區塊",
    "Network connection error: Could not connect to the document" : "網路連線錯誤：無法連線至文件",
    "Last save {lastSave}" : "上次儲存於 {lastSave}",
    "Show image" : "顯示影像",
    "Show file" : "顯示檔案"
},
"nplurals=1; plural=0;");

==> nextcloud-20.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/zh_TW.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "Nextcloud 文字編輯器",
    "text document" : "文字文件",
    "Readme" : "說明",
    "Text" : "文字編輯器",
    "📝 Collaborative document editing" : "📝 協作文件編輯",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 協作文件編輯！**\n\n- **📝 聚焦編輯：** 沒有不重要的東西，只有你需要的格式化。\n- **🙋 共同作業：** 與朋友及同事協作，無關他們是否使用 Nextcloud！\n- **💾 開放格式：** 檔案會以 [Markdown](https://en.wikipedia.org/wiki/Markdown) 儲存，所以你也能在其他文字編輯器編輯。\n- **✊ 強大基礎：** 我們使用基於 [🦉 ProseMirror](https://prosemirror.net) 的 [🐈 tiptap](https://tiptap.scrumpy.io) – 超級感謝他們！",
    "Use current version" : "使用目前版本",
    "Use the saved version" : "使用儲存版本",
    "The document has been changed outside of the editor. The changes cannot be applied." : "文件已在編輯器外變更。變更無法套用。",
    "File could not be loaded. Please check your internet connection." : "無法載入檔案。請檢查您的網路連線。",
    "Retry" : "重試",
    "Last saved {lastSaved}" : "上次儲存於 {lastSaved}",
    "Unpushed changes" : "未推送變更",
    "Unsaved changes" : "未儲存變更",
    "Enter your name so other users can see who is editing" : "輸入您的名稱，這樣其他使用者才能查看是誰在編輯",
    "Edit guest name" : "編輯訪客名稱",
    "Save guest name" : "儲存訪客名稱",
    "Insert image" : "插入影像",
    "_and %n other editor_::_and %n other editors_" : ["及其他 %n 個編輯器"],
    "Show rich workspaces" : "顯示較多功能的工作區",
    "Add notes, lists or links …" : "加入筆記、清單或連結…",
    "New text document" : "新文字文件",
    "Edit" : "編輯",
    "Undo" : "復原",
    "Redo" : "重作",
    "Bold" : "粗體",
    "Italic" : "斜體",
    "Strikethrough" : "刪除線",
    "Headings" : "標題",
    "Heading 1" : "標題 1",
    "Heading 2" : "標題 2",
    "Heading 3" : "標題 3",
    "Heading 4" : "標題 4",
    "Heading 5" : "標題 5",
    "Heading 6" : "標題 6",
    "Unordered list" : "無序清單",
    "Ordered list" : "有序清單",
    "ToDo list" : "待辦列表",
    "Blockquote" : "引文",
    "Code block" : "程式碼區塊",
    "Network connection error: Could not connect to the document" : "網路連線錯誤：無法連線至文件",
    "Last save {lastSave}" : "上次儲存於 {lastSave}",
    "Add link" : "加入連結",
    "Show image" : "顯示影像",
    "Show file" : "顯示檔案",
    "Paragraph" : "段落"
},
"nplurals=1; plural=0;");
